@@ -3,14 +3,16 @@ from .errors import AuthenticationError
 
 
 class Controller(Blueprint):
-
-    def __init__(self, name, import_name, require_auth=True,
-                 auth_error_class=None, **kwargs):
+    def __init__(
+        self, name, import_name, require_auth=True, auth_error_class=None, **kwargs
+    ):
         super().__init__(name, import_name, **kwargs)
 
         if auth_error_class is None:
             auth_error_class = AuthenticationError
-        if type(auth_error_class) != type or not issubclass(auth_error_class, Exception):
+        if type(auth_error_class) != type or not issubclass(
+            auth_error_class, Exception
+        ):
             raise TypeError("auth_error_class must be a subclass of Exception")
         self.auth_error = auth_error_class
 
