@@ -32,10 +32,15 @@ class Field:
         default=None,
         index=None,
         unique=False,
+        choices=None,
     ):
         self.required = required
         self.rejected = rejected
         self.restricted = restricted
+        if choices:
+            self.choices = set(choices)
+        else:
+            self.choices = None
         self.def_value = default
         self.index, self.index_options = self.__generate_index(index, unique)
         self.name = None
@@ -62,6 +67,14 @@ class Field:
         if self.required and value is None:
             raise ValidationError(f"field {self.name} is required")
 
+        if self.choices and value not in self.choices:
+            if value is None:
+                # at this point the value can be None only if it's not required
+                # thus, if it's not required, it's ok to be None even if choices are defined
+                return
+
+            raise ValidationError(f"field {self.name} must be one of {self.choices}")
+
 
 class TypedField(Field):
 
